js.fontawesome
**************

Introduction
============

This library packages `Font Awesome`_ for `fanstatic`_.

.. _`fanstatic`: http://fanstatic.org
.. _`Font Awesome`: https://fontawesome.com

This requires integration between your web framework and ``fanstatic``,
and making sure that the original resources (shipped in the ``resources``
directory in ``js.fontawesome``) are published to some URL.

